--[[----------------------------------------------------------------------
      MinimapButton Module - Part of VanasKoS
Creates a MinimapButton with a menu for VanasKoS
------------------------------------------------------------------------]]

local L = AceLibrary("AceLocale-2.2"):new("VanasKoSMinimapButton");

L:RegisterTranslations("enUS", function() return {
	["Main Window"] = true,
	["KoS Warning Window"] = true,
	["Add Player to KoS"] = true,
	["Add Guild to KoS"] = true,
	["Add Player to Hatelist"] = true,
	["Add Player to Nicelist"] = true,
	["Minimap Button"] = true,
	["Enabled"] = true,
	["Angle"] = true,
	["Distance"] = true,
} end);

L:RegisterTranslations("deDE", function() return {
	["Main Window"] = "Programmfenster",
	["KoS Warning Window"] = "KoS-Warnfenster",
	["Add Player to KoS"] = "Spieler zur KoS-Liste hinzufuegen",
	["Add Guild to KoS"] = "Gilde zur KoS-Liste hinzufuegen",
	["Add Player to Hatelist"] = "Spieler zur Hassliste hinzufuegen",
	["Add Player to Nicelist"] = "Spieler zur Nette-Leuteliste hinzufuegen",
	["Minimap Button"] = "Minimap Button",
	["Enabled"] = "Aktiviert",
	["Angle"] = "Winkel",
	["Distance"] = "Abstand",
} end);

L:RegisterTranslations("frFR", function() return {
	["Main Window"] = "Fen\195\170tre principale",
	["KoS Warning Window"] = "Fen\195\170tre d'avertissement KoS",
	["Add Player to KoS"] = "Ajouter un joueur KoS",
	["Add Guild to KoS"] = "Ajouter une guilde KoS",
	["Add Player to Hatelist"] = "Ajouter un joueur \195\160 la liste noire",
	["Add Player to Nicelist"] = "Ajouter un joueur \195\160 la liste blanche",	
	["Minimap Button"] = "Bouton Minicarte",
	["Enabled"] = "Actif",
	["Angle"] = "Angle",
	["Distance"] = "Distance",
} end);
					
L:RegisterTranslations("koKR", function() return {
	["Main Window"] = "메인창",
	["KoS Warning Window"] = "KoS 경고창",
	["Add Player to KoS"] = "KoS에 플레이어 추가",
	["Add Guild to KoS"] = "KoS에 길드 추가",
	["Add Player to Hatelist"] = "적대적 목록에 플레이어 추가",
	["Add Player to Nicelist"] = "우호적 목록에 플레이어 추가",
	["Minimap Button"] = "미니맵 버튼",
	["Enabled"] = "사용중",
	["Angle"] = "각도",
	["Distance"] = "거리",
} end);

VanasKoSMinimapButton = VanasKoS:NewModule("MinimapButton");

local dewdrop = AceLibrary("Dewdrop-2.0");
local ang = 290
local r = 75;

function VanasKoSMinimapButton:OnInitialize()
	local name = "VanasKoS_MinimapButton";
	self.frame = CreateFrame("Button", name, Minimap);
	
	local frame = self.frame;
	
	frame:SetWidth(31);
	frame:SetHeight(31);
	frame:SetFrameStrata("LOW");
	frame:SetToplevel(1);
	frame:SetHighlightTexture("Interface\\Minimap\\UI-Minimap-ZoomButton-Highlight");
	frame:SetPoint("TOPLEFT", "Minimap", "TOPLEFT");
	
	local button = frame:CreateTexture(name .. "Texture", "BACKGROUND");
	button:SetTexture("Interface\\Icons\\Ability_Parry");
	button:SetWidth(20);
	button:SetHeight(20);
	button:SetPoint("TOPLEFT", frame, "TOPLEFT", 7, -5);
	
	local overlay = frame:CreateTexture(name .. "Overlay", "OVERLAY");
	overlay:SetTexture("Interface\\Minimap\\MiniMap-TrackingBorder");
	overlay:SetWidth(53);
	overlay:SetHeight(53);
	overlay:SetPoint("TOPLEFT", frame, "TOPLEFT");
	
	dewdrop:Register(frame, 
			'children', function()
							dewdrop:AddLine(
								'text', VANASKOS.NAME .. " " .. VANASKOS.VERSION,
								'isTitle', true,
								'justifyH', "CENTER"
							);
							dewdrop:AddLine(
								'text', L["Main Window"],
								'func', function() VanasKoS:ToggleMenu(); end,
								'checked', VanasKoSFrame:IsVisible()
							);
							dewdrop:AddLine(
								'text', L["KoS Warning Window"],
								'func', function() VanasKoS:TogOpt("enableWarnFrame"); VanasKoS:ToggleModuleActive("WarnFrame", VanasKoS:GetOpt("enabledWarnFrame")); VanasKoSWarnFrame:Update();end,
								'checked', VanasKoS:GetOpt("enableWarnFrame")
							);
							dewdrop:AddLine(
								'text', L["Add Player to KoS"],
								'func', function() VanasKoS:AddEntryFromTarget("PLAYERKOS") end
							);
							dewdrop:AddLine(
								'text', L["Add Guild to KoS"],
								'func', function() 
											local guild = nil;
											if(UnitIsPlayer("target")) then
												guild = GetGuildInfo("target");
											end
											VanasKoS:AddEntryFromTarget("GUILDKOS", guild);
										end
							);
							dewdrop:AddLine(
								'text', L["Add Player to Hatelist"],
								'func', function() VanasKoS:AddEntryFromTarget("HATELIST"); end
							);
							dewdrop:AddLine(
								'text', L["Add Player to Nicelist"],
								'func', function() VanasKoS:AddEntryFromTarget("NICELIST"); end
							);

						end,
			'dontHook', true);
	
	frame:RegisterForClicks("LeftButtonUp", "RightButtonUp");

	frame:SetScript("OnClick", self.OnClick);
	VanasKoSGUI:AddConfigOption("MinimapButton", {
			type = 'group',
			name = L["Minimap Button"],
			desc = L["Minimap Button"],
			args = {
				enabled = {
					type = 'toggle',
					name = L["Enabled"],
					desc = L["Enabled"],
					order = 1,
					set = function() VanasKoS:TogOpt("MinimapButtonEnabled"); VanasKoS:ToggleModuleActive("MinimapButton", VanasKoS:GetOpt("MinimapButtonEnabled")); end,
					get = function() return VanasKoS:GetOpt("MinimapButtonEnabled"); end,
				},
				angle = {
					type = 'range',
					name = L["Angle"],
					desc = L["Angle"],
					min = 0,
					max = 360,
					step = 1,
					set = function(value) VanasKoSMinimapButton:SetAngle(value); VanasKoS:SetOpt("MinimapButtonAngle", value); end,
					get = function() return  VanasKoS:GetOpt("MinimapButtonAngle"); end,
				},
				distance = {
					type = 'range',
					name = L["Distance"],
					desc = L["Distance"],
					min = 40,
					max = 150,
					step = 1,
					set = function(value) VanasKoSMinimapButton:SetDist(value); VanasKoS:SetOpt("MinimapButtonDist", value); end,
					get = function() return  VanasKoS:GetOpt("MinimapButtonDist"); end,
				}

			}
		});
	
	self.frame:Hide();
end

function VanasKoSMinimapButton:SetPosition()
	self.frame:SetPoint("TOPLEFT", "Minimap", "TOPLEFT", 58 - (r * cos(ang)), (r * sin(ang)) - 58);
end

function VanasKoSMinimapButton:SetAngle(newang)
	ang = newang;
	self:SetPosition();
end

function VanasKoSMinimapButton:SetDist(newdist)
	r = newdist;
	self:SetPosition();
end

function VanasKoSMinimapButton:Toggle()
	if(self.frame:IsVisible()) then
		self.frame:Hide();
	else
		self.frame:Show();
	end
end

function VanasKoSMinimapButton:OnClick()
	if(arg1 == "LeftButton") then
		dewdrop:Open(VanasKoSMinimapButton.frame);
	end
	if(arg1 == "RightButton") then
		VanasKoS:AddEntryFromTarget("PLAYERKOS");
	end
end

function VanasKoSMinimapButton:OnEnable()
	if(VanasKoS:GetOpt("MinimapButtonAngle")) then
		ang = VanasKoS:GetOpt("MinimapButtonAngle");
	end
	if(VanasKoS:GetOpt("MinimapButtonDist")) then
		r = VanasKoS:GetOpt("MinimapButtonDist");
	end

	if(not VanasKoS:GetOpt("MinimapButtonEnabled")) then
		self.frame:Hide();
		return;
	end

	self.frame:SetPoint("TOPLEFT", "Minimap", "TOPLEFT", 58 - (r * cos(ang)), (r * sin(ang)) - 58);

	self.frame:Show();
end

function VanasKoSMinimapButton:OnDisable()
	self.frame:Hide();
end

